@@ -46,6 +46,7 @@ CSpellchecker::CSpellchecker (const QString &lang, const QString &path,
                               const QString &user_path):
                               ASpellchecker (lang, path, user_path)
 {
+  qDebug() << "start ASpeller";
   ret = 0;
   speller = 0;
   spell_config = 0;
@@ -219,7 +220,7 @@ QStringList CSpellchecker::get_suggestions_list (const QString &word)
 
 CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, const QString &user_path): ASpellchecker (lang, path, user_path)
 {
-//  qDebug() << "CHunspellChecker::CHunspellChecker - start";
+  qDebug() << "CHunspellChecker::CHunspellChecker - start";
 
   initialized = false;
 
@@ -287,7 +288,7 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
 
 #endif
 
-//  qDebug() << "CHunspellChecker::CHunspellChecker - end";
+  qDebug() << "CHunspellChecker::CHunspellChecker - end";
 }
 
 
@@ -384,12 +385,17 @@ bool CHunspellChecker::check (const QString &word)
 {
   if (! initialized)
       return false;
+      
+  //if (word.isEmpty())
+    // return false;    
 
  QTextCodec *codec = QTextCodec::codecForName (encoding);
  QByteArray es = codec->fromUnicode (word);
  
 #ifndef H_DEPRECATED
-  return speller->spell (es.data()); //old way
+
+   return speller->spell (es.constData()); 
+  //return speller->spell (es.data()); //old way
 #else  
   return speller->spell (QString(es).toStdString());
 #endif
@@ -467,4 +473,4 @@ QStringList CHunspellChecker::get_suggestions_list (const QString &word)
   return sl;
 }
 
-#endif 
+#endif
